<?php

namespace Drupal\field_fallback\Plugin;

use Drupal\Component\Plugin\ConfigurableInterface;
use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Plugin\PluginFormInterface;
use Drupal\field\FieldConfigInterface;

/**
 * Interface for field fallback converter plugins.
 */
interface FieldFallbackConverterInterface extends PluginInspectionInterface, ConfigurableInterface, PluginFormInterface {

  /**
   * Get the source fields for which the plugin calculates the fallback value.
   *
   * @return string[]
   *   An array of source fields.
   */
  public function getSource(): array;

  /**
   * Get the target fields for which the plugin calculates the fallback value.
   *
   * @return string[]
   *   An array of target fields.
   */
  public function getTarget(): array;

  /**
   * Get the weight of the plugin.
   *
   * @return int
   *   The weight of the plugin.
   */
  public function getWeight(): int;

  /**
   * Converts the value of the given field to a new value.
   *
   * @param \Drupal\Core\Field\FieldItemListInterface $field
   *   The source field. The field used to calculate the value.
   *
   * @return mixed
   *   The converted value.
   */
  public function convert(FieldItemListInterface $field);

  /**
   * Set the entity.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   The entity.
   *
   * @return $this
   *   the called converter.
   */
  public function setEntity(ContentEntityInterface $entity): FieldFallbackConverterInterface;

  /**
   * Set the target field.
   *
   * @param \Drupal\field\FieldConfigInterface $field_config
   *   The target field.
   *
   * @return $this
   *   the called converter.
   */
  public function setTargetField(FieldConfigInterface $field_config): FieldFallbackConverterInterface;

}
